@@ -1,16 +1,20 @@
 from sanic.__version__ import __version__
 from sanic.app import Sanic
 from sanic.blueprints import Blueprint
+from sanic.constants import HTTPMethod
 from sanic.request import Request
 from sanic.response import HTTPResponse, html, json, text
+from sanic.server.websockets.impl import WebsocketImplProtocol as Websocket
 
 
 __all__ = (
     "__version__",
     "Sanic",
     "Blueprint",
+    "HTTPMethod",
     "HTTPResponse",
     "Request",
+    "Websocket",
     "html",
     "json",
     "text",
