@@ -25,6 +25,10 @@ class AsyncMock(Mock):
     def __await__(self):
         return self().__await__()
 
+    def reset_mock(self, *args, **kwargs):
+        super().reset_mock(*args, **kwargs)
+        self.await_count = 0
+
     def assert_awaited_once(self):
         if not self.await_count == 1:
             msg = (
@@ -32,3 +36,13 @@ class AsyncMock(Mock):
                 f" Awaited {self.await_count} times."
             )
             raise AssertionError(msg)
+
+    def assert_awaited_once_with(self, *args, **kwargs):
+        if not self.await_count == 1:
+            msg = (
+                f"Expected to have been awaited once."
+                f" Awaited {self.await_count} times."
+            )
+            raise AssertionError(msg)
+        self.assert_awaited_once()
+        return self.assert_called_with(*args, **kwargs)
