@@ -9,10 +9,11 @@ import uvicorn
 from sanic import Sanic
 from sanic.application.state import Mode
 from sanic.asgi import MockTransport
-from sanic.exceptions import Forbidden, InvalidUsage, ServiceUnavailable
+from sanic.exceptions import BadRequest, Forbidden, ServiceUnavailable
 from sanic.request import Request
 from sanic.response import json, text
 from sanic.server.websockets.connection import WebSocketConnection
+from sanic.signals import RESERVED_NAMESPACES
 
 
 @pytest.fixture
@@ -221,6 +222,7 @@ def test_listeners_triggered_async(app, caplog):
     assert after_server_stop
 
     app.state.mode = Mode.DEBUG
+    app.state.verbosity = 0
     with caplog.at_level(logging.DEBUG):
         server.run()
 
@@ -392,7 +394,7 @@ async def test_websocket_accept_with_multiple_subprotocols(
 
 
 def test_improper_websocket_connection(transport, send, receive):
-    with pytest.raises(InvalidUsage):
+    with pytest.raises(BadRequest):
         transport.get_websocket_connection()
 
     transport.create_websocket_connection(send, receive)
@@ -415,7 +417,7 @@ async def test_request_class_custom():
     class MyCustomRequest(Request):
         pass
 
-    app = Sanic(name=__name__, request_class=MyCustomRequest)
+    app = Sanic(name="Test", request_class=MyCustomRequest)
 
     @app.get("/custom")
     def custom_request(request):
@@ -513,3 +515,44 @@ async def test_request_exception_suppressed_by_middleware(app):
 
     _, response = await app.asgi_client.get("/error-prone")
     assert response.status_code == 403
+
+
+@pytest.mark.asyncio
+async def test_signals_triggered(app):
+    @app.get("/test_signals_triggered")
+    async def _request(request):
+        return text("test_signals_triggered")
+
+    signals_triggered = []
+    signals_expected = [
+        # "http.lifecycle.begin",
+        # "http.lifecycle.read_head",
+        "http.lifecycle.request",
+        "http.lifecycle.handle",
+        "http.routing.before",
+        "http.routing.after",
+        "http.lifecycle.response",
+        # "http.lifecycle.send",
+        # "http.lifecycle.complete",
+    ]
+
+    def signal_handler(signal):
+        return lambda *a, **kw: signals_triggered.append(signal)
+
+    for signal in RESERVED_NAMESPACES["http"]:
+        app.signal(signal)(signal_handler(signal))
+
+    _, response = await app.asgi_client.get("/test_signals_triggered")
+    assert response.status_code == 200
+    assert response.text == "test_signals_triggered"
+    assert signals_triggered == signals_expected
+
+
+@pytest.mark.asyncio
+async def test_asgi_serve_location(app):
+    @app.get("/")
+    def _request(request: Request):
+        return text(request.app.serve_location)
+
+    _, response = await app.asgi_client.get("/")
+    assert response.text == "http://<ASGI>"
