@@ -3,12 +3,7 @@ from pytest import raises
 from sanic.app import Sanic
 from sanic.blueprint_group import BlueprintGroup
 from sanic.blueprints import Blueprint
-from sanic.exceptions import (
-    Forbidden,
-    InvalidUsage,
-    SanicException,
-    ServerError,
-)
+from sanic.exceptions import BadRequest, Forbidden, SanicException, ServerError
 from sanic.request import Request
 from sanic.response import HTTPResponse, text
 
@@ -104,7 +99,7 @@ def test_bp_group(app: Sanic):
 
     @blueprint_1.route("/invalid")
     def blueprint_1_error(request: Request):
-        raise InvalidUsage("Invalid")
+        raise BadRequest("Invalid")
 
     @blueprint_2.route("/")
     def blueprint_2_default_route(request):
@@ -120,7 +115,7 @@ def test_bp_group(app: Sanic):
 
     blueprint_3 = Blueprint("blueprint_3", url_prefix="/bp3")
 
-    @blueprint_group_1.exception(InvalidUsage)
+    @blueprint_group_1.exception(BadRequest)
     def handle_group_exception(request, exception):
         return text("BP1_ERR_OK")
 
