@@ -3,10 +3,13 @@ import inspect
 import os
 
 from collections import namedtuple
+from datetime import datetime
+from email.utils import formatdate
 from logging import ERROR, LogRecord
 from mimetypes import guess_type
+from pathlib import Path
 from random import choice
-from typing import Callable, List
+from typing import Callable, List, Union
 from urllib.parse import unquote
 
 import pytest
@@ -24,7 +27,6 @@ from sanic.response import (
     file_stream,
     json,
     raw,
-    stream,
     text,
 )
 
@@ -46,10 +48,13 @@ def test_response_body_not_a_string(app):
     assert b"Internal Server Error" in response.body
 
 
-async def sample_streaming_fn(response):
-    await response.write("foo,")
+async def sample_streaming_fn(request, response=None):
+    if not response:
+        response = await request.respond(content_type="text/csv")
+    await response.send("foo,")
     await asyncio.sleep(0.001)
-    await response.write("bar")
+    await response.send("bar")
+    await response.eof()
 
 
 def test_method_not_allowed():
@@ -98,11 +103,12 @@ def test_response_header(app):
         return json({"ok": True}, headers={"CONTENT-TYPE": "application/json"})
 
     request, response = app.test_client.get("/")
-    assert dict(response.headers) == {
+    for key, value in {
         "connection": "keep-alive",
         "content-length": "11",
         "content-type": "application/json",
-    }
+    }.items():
+        assert response.headers[key] == value
 
 
 def test_response_content_length(app):
@@ -213,10 +219,7 @@ def test_no_content(json_app):
 def streaming_app(app):
     @app.route("/")
     async def test(request: Request):
-        return stream(
-            sample_streaming_fn,
-            content_type="text/csv",
-        )
+        await sample_streaming_fn(request)
 
     return app
 
@@ -225,11 +228,11 @@ def streaming_app(app):
 def non_chunked_streaming_app(app):
     @app.route("/")
     async def test(request: Request):
-        return stream(
-            sample_streaming_fn,
+        response = await request.respond(
             headers={"Content-Length": "7"},
             content_type="text/csv",
         )
+        await sample_streaming_fn(request, response)
 
     return app
 
@@ -279,18 +282,6 @@ def test_non_chunked_streaming_returns_correct_content(
     assert response.text == "foo,bar"
 
 
-def test_stream_response_with_cookies_legacy(app):
-    @app.route("/")
-    async def test(request: Request):
-        response = stream(sample_streaming_fn, content_type="text/csv")
-        response.cookies["test"] = "modified"
-        response.cookies["test"] = "pass"
-        return response
-
-    request, response = app.test_client.get("/")
-    assert response.cookies["test"] == "pass"
-
-
 def test_stream_response_with_cookies(app):
     @app.route("/")
     async def test(request: Request):
@@ -313,7 +304,7 @@ def test_stream_response_with_cookies(app):
 def test_stream_response_without_cookies(app):
     @app.route("/")
     async def test(request: Request):
-        return stream(sample_streaming_fn, content_type="text/csv")
+        await sample_streaming_fn(request)
 
     request, response = app.test_client.get("/")
     assert response.cookies == {}
@@ -328,12 +319,27 @@ def static_file_directory():
     return static_directory
 
 
-def get_file_content(static_file_directory, file_name):
+def path_str_to_path_obj(static_file_directory: Union[Path, str]):
+    if isinstance(static_file_directory, str):
+        static_file_directory = Path(static_file_directory)
+    return static_file_directory
+
+
+def get_file_content(static_file_directory: Union[Path, str], file_name: str):
     """The content of the static file to check"""
-    with open(os.path.join(static_file_directory, file_name), "rb") as file:
+    static_file_directory = path_str_to_path_obj(static_file_directory)
+    with open(static_file_directory / file_name, "rb") as file:
         return file.read()
 
 
+def get_file_last_modified_timestamp(
+    static_file_directory: Union[Path, str], file_name: str
+):
+    """The content of the static file to check"""
+    static_file_directory = path_str_to_path_obj(static_file_directory)
+    return (static_file_directory / file_name).stat().st_mtime
+
+
 @pytest.mark.parametrize(
     "file_name", ["test.file", "decode me.txt", "python.png"]
 )
@@ -711,3 +717,84 @@ def send_response_after_eof_should_fail(
         assert "foo, " in response.text
         assert message_in_records(caplog.records, error_msg1)
         assert message_in_records(caplog.records, error_msg2)
+
+
+@pytest.mark.parametrize(
+    "file_name", ["test.file", "decode me.txt", "python.png"]
+)
+def test_file_response_headers(
+    app: Sanic, file_name: str, static_file_directory: str
+):
+    test_last_modified = datetime.now()
+    test_max_age = 10
+    test_expires = test_last_modified.timestamp() + test_max_age
+
+    @app.route("/files/cached/<filename>", methods=["GET"])
+    def file_route_cache(request, filename):
+        file_path = (Path(static_file_directory) / file_name).absolute()
+        return file(
+            file_path, max_age=test_max_age, last_modified=test_last_modified
+        )
+
+    @app.route(
+        "/files/cached_default_last_modified/<filename>", methods=["GET"]
+    )
+    def file_route_cache_default_last_modified(request, filename):
+        file_path = (Path(static_file_directory) / file_name).absolute()
+        return file(file_path, max_age=test_max_age)
+
+    @app.route("/files/no_cache/<filename>", methods=["GET"])
+    def file_route_no_cache(request, filename):
+        file_path = (Path(static_file_directory) / file_name).absolute()
+        return file(file_path)
+
+    @app.route("/files/no_store/<filename>", methods=["GET"])
+    def file_route_no_store(request, filename):
+        file_path = (Path(static_file_directory) / file_name).absolute()
+        return file(file_path, no_store=True)
+
+    _, response = app.test_client.get(f"/files/cached/{file_name}")
+    assert response.body == get_file_content(static_file_directory, file_name)
+    headers = response.headers
+    assert (
+        "cache-control" in headers
+        and f"max-age={test_max_age}" in headers.get("cache-control")
+        and f"public" in headers.get("cache-control")
+    )
+    assert (
+        "expires" in headers
+        and headers.get("expires")[:-6]
+        == formatdate(test_expires, usegmt=True)[:-6]
+        # [:-6] to allow at most 1 min difference
+        # It's minimal for cases like:
+        # Thu, 26 May 2022 05:36:49 GMT
+        # AND
+        # Thu, 26 May 2022 05:36:50 GMT
+    )
+
+    assert "last-modified" in headers and headers.get(
+        "last-modified"
+    ) == formatdate(test_last_modified.timestamp(), usegmt=True)
+
+    _, response = app.test_client.get(
+        f"/files/cached_default_last_modified/{file_name}"
+    )
+    file_last_modified = get_file_last_modified_timestamp(
+        static_file_directory, file_name
+    )
+    headers = response.headers
+    assert "last-modified" in headers and headers.get(
+        "last-modified"
+    ) == formatdate(file_last_modified, usegmt=True)
+
+    _, response = app.test_client.get(f"/files/no_cache/{file_name}")
+    headers = response.headers
+    assert "cache-control" in headers and f"no-cache" == headers.get(
+        "cache-control"
+    )
+
+    _, response = app.test_client.get(f"/files/no_store/{file_name}")
+    headers = response.headers
+    assert "cache-control" in headers and f"no-store" == headers.get(
+        "cache-control"
+    )
