@@ -1,5 +1,6 @@
+from sanic_testing.testing import PORT, SanicTestClient
+
 from sanic.response import json, text
-from sanic.testing import PORT, SanicTestClient
 
 
 # ------------------------------------------------------------ #
